@@ -3,6 +3,7 @@ use std::io;
 use std::net::SocketAddr;
 use std::net::UdpSocket as StdUdpSocket;
 use tokio;
+use log::{info};
 
 const DEFAULT_MAX_DATAGRAM_SIZE: usize = 1350;
 const DEFAULT_MAX_IDLE_TIMEOUT: u64 = 5000;
@@ -294,6 +295,7 @@ impl QuicListener {
                 Ok((write, send_info)) => {
                     info = Some(send_info);
                     write_idx = Some(write);
+                    break;
                 }
 
                 Err(quiche::Error::Done) => {
@@ -323,6 +325,7 @@ impl QuicListener {
         out: &mut [u8],
         info: &quiche::SendInfo,
     ) -> Result<usize, std::io::Error> {
+        info!("in send to");
         self.socket.inner.send_to(out, info.to).await
     }
 
@@ -344,6 +347,7 @@ impl QuicListener {
     /// ```
     pub async fn recv(&mut self, buf: &mut [u8]) -> Result<usize, io::Error> {
         loop {
+            info!("in recv");
             let (read, from) = match self.recv_from(buf).await {
                 Ok(v) => v,
                 Err(e) => return Err(io::Error::new(io::ErrorKind::InvalidData, e)),
@@ -361,6 +365,7 @@ impl QuicListener {
         &self,
         buf: &mut [u8],
     ) -> Result<(usize, std::net::SocketAddr), std::io::Error> {
+        info!("in recv from");
         self.socket.inner.recv_from(buf).await
     }
 
